
API Documentation
=================

Everything you could ever want to know about SMRF.

.. toctree::
   
   smrf.data
   smrf.distribute
   smrf.envphys
   smrf.framework
   smrf.output
   smrf.spatial
   smrf.utils